@@ -55,6 +55,10 @@ AD_BLOCK_LIST = [
     'iframe[id*="_ads_frame"]',
     'iframe[style="height:0px;width:0px;display:none;"]',
     '[aria-label="Ad"]',
+    '[aria-label="Timeline: Trending now"]',
+    '[aria-label="Timeline: Carousel"]',
+    '[aria-roledescription="carousel"]',
+    '[aria-label="Who to follow"]',
     '[class*="sponsored-content"]',
     '[class*="adsbygoogle"]',
     '[class^="adroll"]',
@@ -75,6 +79,7 @@ AD_BLOCK_LIST = [
     '[href*="doubleclick"]',
     '[href*="amazon-adsystem"]',
     '[alt="Advertisement"]',
+    '[alt$=" Ad"]',
     '[id*="-ad-"]',
     '[id*="_ads_"]',
     '[id*="AdFrame"]',
