@@ -1,6 +1,4 @@
-"""
-This tool allows testers to quickly verify pages while assisted by automation.
-"""
+"""Manually verify pages quickly while assisted by automation."""
 import os
 import shutil
 import sys
@@ -8,20 +6,16 @@ import time
 from selenium.common.exceptions import NoAlertPresentException
 from selenium.common.exceptions import WebDriverException
 from seleniumbase import BaseCase
-from seleniumbase.core.style_sheet import style
+from seleniumbase.core.style_sheet import get_report_style
 from seleniumbase.config import settings
 from seleniumbase.fixtures import js_utils
 
-python3 = True
-if sys.version_info[0] < 3:
-    python3 = False
-
 
 class MasterQA(BaseCase):
     def setUp(self):
         self.check_count = 0
         self.auto_close_results_page = False
-        super(MasterQA, self).setUp(masterqa_mode=True)
+        super().setUp(masterqa_mode=True)
         self.LATEST_REPORT_DIR = settings.LATEST_REPORT_DIR
         self.ARCHIVE_DIR = settings.REPORT_ARCHIVE_DIR
         self.RESULTS_PAGE = settings.HTML_REPORT
@@ -71,7 +65,7 @@ class MasterQA(BaseCase):
         if self.__has_exception():
             self.__add_failure(sys.exc_info()[1])
         self.__process_manual_check_results(self.auto_close_results_page)
-        super(MasterQA, self).tearDown()
+        super().tearDown()
 
     ####################
 
@@ -89,35 +83,35 @@ class MasterQA(BaseCase):
         self, archive_past_runs=True, get_log_folder=False
     ):
         abs_path = os.path.abspath(".")
-        file_path = abs_path + "/%s" % self.LATEST_REPORT_DIR
+        file_path = os.path.join(abs_path, self.LATEST_REPORT_DIR)
         if not os.path.exists(file_path):
             os.makedirs(file_path)
 
         if archive_past_runs:
             archive_timestamp = int(time.time())
-            if not os.path.exists("%s/../%s/" % (file_path, self.ARCHIVE_DIR)):
-                os.makedirs("%s/../%s/" % (file_path, self.ARCHIVE_DIR))
-            archive_dir = "%s/../%s/log_%s" % (
-                file_path,
-                self.ARCHIVE_DIR,
-                archive_timestamp,
+            archive_dir_root = os.path.join(file_path, "..", self.ARCHIVE_DIR)
+            if not os.path.exists(archive_dir_root):
+                os.makedirs(archive_dir_root)
+            archive_dir = os.path.join(
+                archive_dir_root, "log_%s" % archive_timestamp
             )
             shutil.move(file_path, archive_dir)
             os.makedirs(file_path)
             if get_log_folder:
                 return archive_dir
         else:
+            latest_report_local = os.path.join(".", self.LATEST_REPORT_DIR)
             # Just delete bad pages to make room for the latest run.
             filelist = [
                 f
-                for f in os.listdir("./%s" % self.LATEST_REPORT_DIR)
+                for f in os.listdir(latest_report_local)
                 if (f.startswith("failed_"))
                 or (f == self.RESULTS_PAGE)
                 or (f.startswith("automation_failure"))
                 or (f == self.BAD_PAGE_LOG)
             ]
             for f in filelist:
-                os.remove("%s/%s" % (file_path, f))
+                os.remove(os.path.join(file_path, f))
 
     def __jq_confirm_dialog(self, question):
         count = self.manual_check_count + 1
@@ -197,7 +191,8 @@ class MasterQA(BaseCase):
             get_jqc = None
             try:
                 get_jqc = self.execute_script("return jconfirm")
-                get_jqc = get_jqc["instances"]
+                if get_jqc is None:
+                    raise Exception("jconfirm did not load")
                 use_jqc = True
             except Exception:
                 use_jqc = False
@@ -313,19 +308,11 @@ class MasterQA(BaseCase):
         has_exception = False
         if hasattr(sys, "last_traceback") and sys.last_traceback is not None:
             has_exception = True
-        elif python3 and hasattr(self, "_outcome"):
+        elif hasattr(self, "_outcome"):
             if hasattr(self._outcome, "errors") and self._outcome.errors:
                 has_exception = True
         else:
-            if python3:
-                has_exception = sys.exc_info()[1] is not None
-            else:
-                if not hasattr(self, "_using_sb_fixture_class") and (
-                    not hasattr(self, "_using_sb_fixture_no_class")
-                ):
-                    has_exception = sys.exc_info()[1] is not None
-                else:
-                    has_exception = len(str(sys.exc_info()[1]).strip()) > 0
+            has_exception = sys.exc_info()[1] is not None
         return has_exception
 
     def __add_failure(self, exception=None):
@@ -364,8 +351,8 @@ class MasterQA(BaseCase):
 
     def __add_bad_page_log_file(self):
         abs_path = os.path.abspath(".")
-        file_path = abs_path + "/%s" % self.LATEST_REPORT_DIR
-        log_file = "%s/%s" % (file_path, self.BAD_PAGE_LOG)
+        file_path = os.path.join(abs_path, self.LATEST_REPORT_DIR)
+        log_file = os.path.join(file_path, self.BAD_PAGE_LOG)
         f = open(log_file, "w")
         h_p1 = """"Num","Result","Screenshot","URL","Browser","Epoch Time","""
         h_p2 = """"Verification Instructions","Additional Info"\n"""
@@ -377,9 +364,9 @@ class MasterQA(BaseCase):
 
     def __add_results_page(self, html):
         abs_path = os.path.abspath(".")
-        file_path = abs_path + "/%s" % self.LATEST_REPORT_DIR
+        file_path = os.path.join(abs_path, self.LATEST_REPORT_DIR)
         results_file_name = self.RESULTS_PAGE
-        results_file = "%s/%s" % (file_path, results_file_name)
+        results_file = os.path.join(file_path, results_file_name)
         f = open(results_file, "w")
         f.write(html)
         f.close()
@@ -394,7 +381,7 @@ class MasterQA(BaseCase):
         if self.manual_check_successes == self.manual_check_count:
             pass
         else:
-            print("WARNING: There were page issues detected!")
+            print("WARNING: Not all tests passed manual inspection!")
             perfection = False
 
         if self.incomplete_runs > 0:
@@ -411,10 +398,10 @@ class MasterQA(BaseCase):
         self.__add_bad_page_log_file()  # Includes successful results
 
         log_string = self.__clear_out_old_logs(get_log_folder=True)
-        log_folder = log_string.split("/")[-1]
+        log_folder = log_string.split(os.sep)[-1]
         abs_path = os.path.abspath(".")
-        file_path = abs_path + "/%s" % self.ARCHIVE_DIR
-        log_path = "%s/%s" % (file_path, log_folder)
+        file_path = os.path.join(abs_path, self.ARCHIVE_DIR)
+        log_path = os.path.join(file_path, log_folder)
         web_log_path = "file://%s" % log_path
 
         tf_color = "#11BB11"
@@ -448,11 +435,12 @@ class MasterQA(BaseCase):
             % summary_table
         )
 
-        log_link_shown = "../%s%s/" % (
-            self.ARCHIVE_DIR,
-            web_log_path.split(self.ARCHIVE_DIR)[1],
+        log_link_shown = os.path.join(
+            "..", "%s%s" % (
+                self.ARCHIVE_DIR, web_log_path.split(self.ARCHIVE_DIR)[1]
+            )
         )
-        csv_link = "%s/%s" % (web_log_path, self.BAD_PAGE_LOG)
+        csv_link = os.path.join(web_log_path, self.BAD_PAGE_LOG)
         csv_link_shown = "%s" % self.BAD_PAGE_LOG
         log_table = """<p><p><p><p><h2><table><tbody>
             <tr><td>LOG FILES LINK:&nbsp;&nbsp;<td><a href="%s">%s</a></tr>
@@ -491,12 +479,12 @@ class MasterQA(BaseCase):
         failure_table += "</tbody></table>"
         table_view = "%s%s%s" % (summary_table, log_table, failure_table)
         report_html = "<html><head>%s</head><body>%s</body></html>" % (
-            style,
+            get_report_style(),
             table_view,
         )
         results_file = self.__add_results_page(report_html)
-        archived_results_file = log_path + "/" + self.RESULTS_PAGE
-        shutil.copyfile(results_file, archived_results_file)
+        archived_results_file = os.path.join(log_path, self.RESULTS_PAGE)
+        shutil.copyfile(results_file, os.path.realpath(archived_results_file))
         if self.manual_check_count > 0:
             print(
                 "\n*** The manual test report is located at:\n" + results_file
@@ -508,5 +496,8 @@ class MasterQA(BaseCase):
         else:
             # The user can decide when to close the results page
             print("\n*** Close the html report window to continue ***")
-            while len(self.driver.window_handles):
-                time.sleep(0.1)
+            try:
+                while len(self.driver.window_handles):
+                    time.sleep(0.1)
+            except Exception:
+                pass
