@@ -1,11 +1,11 @@
-# Russian / Русский - Translations - Python 3 Only!
+# Russian / Русский - Translations
 from seleniumbase import BaseCase
 from seleniumbase import MasterQA
 
 
-class ТестНаСелен(BaseCase):  # noqa
+class ТестНаСелен(BaseCase):
     def __init__(self, *args, **kwargs):
-        super(ТестНаСелен, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._language = "Russian"
 
     def открыть(self, *args, **kwargs):
@@ -24,6 +24,10 @@ class ТестНаСелен(BaseCase):  # noqa
         # double_click(selector)
         return self.double_click(*args, **kwargs)
 
+    def контекстный_щелчок(self, *args, **kwargs):
+        # context_click(selector)
+        return self.context_click(*args, **kwargs)
+
     def нажмите_медленно(self, *args, **kwargs):
         # slow_click(selector)
         return self.slow_click(*args, **kwargs)
@@ -32,10 +36,19 @@ class ТестНаСелен(BaseCase):  # noqa
         # click_if_visible(selector, by=By.CSS_SELECTOR)
         return self.click_if_visible(*args, **kwargs)
 
+    def JS_нажмите_если_присутствует(self, *args, **kwargs):
+        # js_click_if_present(selector, by=By.CSS_SELECTOR)
+        return self.js_click_if_present(*args, **kwargs)
+
     def нажмите_ссылку(self, *args, **kwargs):
         # click_link_text(link_text)
         return self.click_link_text(*args, **kwargs)
 
+    def нажмите_на_местоположение(self, *args, **kwargs):
+        # click_with_offset(selector, x, y, by=By.CSS_SELECTOR,
+        #                   mark=None, timeout=None, center=None)
+        return self.click_with_offset(*args, **kwargs)
+
     def обновить_текст(self, *args, **kwargs):
         # update_text(selector, text)
         return self.update_text(*args, **kwargs)
@@ -64,6 +77,14 @@ class ТестНаСелен(BaseCase):  # noqa
         # assert_link_text(link_text)
         return self.assert_link_text(*args, **kwargs)
 
+    def подтвердить_непустой_текст(self, *args, **kwargs):
+        # assert_non_empty_text(selector)
+        return self.assert_non_empty_text(*args, **kwargs)
+
+    def подтвердить_текст_не_виден(self, *args, **kwargs):
+        # assert_text_not_visible(text, selector)
+        return self.assert_text_not_visible(*args, **kwargs)
+
     def подтвердить_элемент(self, *args, **kwargs):
         # assert_element(selector)
         return self.assert_element(*args, **kwargs)
@@ -88,10 +109,22 @@ class ТестНаСелен(BaseCase):  # noqa
         # assert_attribute(selector, attribute, value)
         return self.assert_attribute(*args, **kwargs)
 
+    def подтвердить_URL(self, *args, **kwargs):
+        # assert_url(url)
+        return self.assert_url(*args, **kwargs)
+
+    def подтвердить_URL_содержит(self, *args, **kwargs):
+        # assert_url_contains(substring)
+        return self.assert_url_contains(*args, **kwargs)
+
     def подтвердить_название(self, *args, **kwargs):
         # assert_title(title)
         return self.assert_title(*args, **kwargs)
 
+    def подтвердить_название_содержит(self, *args, **kwargs):
+        # assert_title_contains(substring)
+        return self.assert_title_contains(*args, **kwargs)
+
     def получить_название(self, *args, **kwargs):
         # get_title()
         return self.get_title(*args, **kwargs)
@@ -136,6 +169,10 @@ class ТестНаСелен(BaseCase):  # noqa
         # is_text_visible(text, selector="html")
         return self.is_text_visible(*args, **kwargs)
 
+    def точный_текст_виден(self, *args, **kwargs):
+        # is_exact_text_visible(text, selector="html")
+        return self.is_exact_text_visible(*args, **kwargs)
+
     def элемент_виден(self, *args, **kwargs):
         # is_element_visible(selector)
         return self.is_element_visible(*args, **kwargs)
@@ -176,6 +213,10 @@ class ТестНаСелен(BaseCase):  # noqa
         # wait_for_attribute(selector, attribute, value)
         return self.wait_for_attribute(*args, **kwargs)
 
+    def ждать_загрузки_страницы(self, *args, **kwargs):
+        # wait_for_ready_state_complete()
+        return self.wait_for_ready_state_complete(*args, **kwargs)
+
     def спать(self, *args, **kwargs):
         # sleep(seconds)
         return self.sleep(*args, **kwargs)
@@ -208,6 +249,18 @@ class ТестНаСелен(BaseCase):  # noqa
         # js_type(selector, text)
         return self.js_type(*args, **kwargs)
 
+    def JQUERY_нажмите(self, *args, **kwargs):
+        # jquery_click(selector)
+        return self.jquery_click(*args, **kwargs)
+
+    def JQUERY_обновить_текст(self, *args, **kwargs):
+        # jquery_update_text(selector, text)
+        return self.jquery_update_text(*args, **kwargs)
+
+    def JQUERY_введите(self, *args, **kwargs):
+        # jquery_type(selector, text)
+        return self.jquery_type(*args, **kwargs)
+
     def проверить_HTML(self, *args, **kwargs):
         # inspect_html()
         return self.inspect_html(*args, **kwargs)
@@ -316,6 +369,10 @@ class ТестНаСелен(BaseCase):  # noqa
         # hover_and_click(hover_selector, click_selector)
         return self.hover_and_click(*args, **kwargs)
 
+    def наведение_мыши(self, *args, **kwargs):
+        # hover(selector)
+        return self.hover(*args, **kwargs)
+
     def выбран(self, *args, **kwargs):
         # is_selected(selector)
         return self.is_selected(*args, **kwargs)
