@@ -3,6 +3,7 @@ import os
 import subprocess
 import sys
 from seleniumbase import drivers  # webdriver storage folder for SeleniumBase
+from seleniumbase.fixtures import shared_utils
 
 DRIVER_DIR = os.path.dirname(os.path.realpath(drivers.__file__))
 # Make sure that the SeleniumBase DRIVER_DIR is at the top of the System PATH
@@ -76,7 +77,7 @@ def main():
 
     data = []
     data.append(verbose)
-    file_path = "%s/%s" % (dir_path, "verbose_hub_server.dat")
+    file_path = os.path.join(dir_path, "verbose_hub_server.dat")
     file = codecs.open(file_path, "w+", "utf-8")
     file.writelines("\r\n".join(data))
     file.close()
@@ -85,7 +86,7 @@ def main():
 
     download_selenium_server.main(force_download=False)  # Only runs if needed
 
-    if "linux" in sys.platform or "darwin" in sys.platform:
+    if shared_utils.is_linux() or shared_utils.is_mac():
         if grid_hub_command == "start":
             subprocess.check_call(
                 dir_path + "/grid-hub start %s" % timeout, shell=True
