@@ -7,8 +7,8 @@
 [[ $0 != "$BASH_SOURCE" ]] && sourced=1 || sourced=0
 if [ $sourced = 1 ]
 then
-  python3 -m pip install --upgrade pip
-  python3 -m pip install virtualenvwrapper --force-reinstall
+  python3 -m pip install --upgrade pip setuptools wheel
+  python3 -m pip install --upgrade virtualenvwrapper --upgrade-strategy=eager
   export WORKON_HOME=$HOME/.virtualenvs
   source `which virtualenvwrapper.sh`
   echo ""
